@@ -76,29 +76,29 @@ def check_is_site(string):
 
     string = string.lower()
 
-    if fx and fx.split('.')[0] in string:
+    if fx and fx in string:
         return "FX"
-    elif sf and sf.split('.')[0] in string:
+    elif sf and sf in string:
         return "SF"
-    elif dw and dw.split('.')[0] in string:
+    elif dw and dw in string:
         return "DW"
-    elif hw and hw.split('.')[0] in string:
+    elif hw and hw in string:
         return "HW"
-    elif ff and ff.split('.')[0] in string:
+    elif ff and ff in string:
         return "FF"
-    elif by and by.split('.')[0] in string:
+    elif by and by in string:
         return "BY"
-    elif nk and nk.split('.')[0] in string:
+    elif nk and nk in string:
         return "NK"
-    elif nx and nx.split('.')[0] in string:
+    elif nx and nx in string:
         return "NX"
-    elif ww and ww.split('.')[0] in string:
+    elif ww and ww in string:
         return "WW"
-    elif sj and sj.split('.')[0] in string:
+    elif sj and sj in string:
         return "SJ"
-    elif dj and dj.split('.')[0] in string:
+    elif dj and dj in string:
         return "DJ"
-    elif dd and dd.split('.')[0] in string:
+    elif dd and dd in string:
         return "DD"
     else:
         return False
@@ -361,6 +361,13 @@ def is_retail(key, delete):
         return False
 
 
+def is_show(title):
+    if re.search(r'S\d{1,3}E\d{1,3}', title, re.IGNORECASE) or re.search(r'S\d{1,3}', title, re.IGNORECASE):
+        return True
+    else:
+        return False
+
+
 def longest_substr(data):
     substr = ''
     if len(data) > 1 and len(data[0]) > 0:
@@ -524,11 +531,11 @@ def site_blocked(url):
     return False
 
 
-def site_blocked_with_flaresolverr(url):
+def site_blocked_with_advanced_methods(url):
     db_status = FeedDb('site_status')
     site = check_is_site(url)
     for check_against in shared_state.sites:
-        if site and check_against == site and db_status.retrieve(check_against + "_flaresolverr"):
+        if site and check_against == site and db_status.retrieve(check_against + "_advanced"):
             return True
     return False
 
